NNCH.select is to be used when a home range has been analyzed
for multiple k's, r's, a's, and/or id's. This function will select a
subset based on user defined conditions of the the original home
range and return a new home range object containing the subset. Most
NNCH functions will accept NNCH.select parameters and call the
function before analyzing data.
summary.NNCH prints out a lengthy data summary containing
rudimentary analysis of the data. Can be saved to a text file.
plot.NNCH generates a plot of the home range.
NNCH.asciigrid creates a raster map of the home range which can
be exported for use by ArcMap and other GIS programs.
NNCH.shapefile creates a representation of the home range as a
polygon shapefile object (can be saved to a shape file thanks to the
package shapefile).NNCH.select(x,id = NULL, k = NULL, r = NULL, a = NULL)
## S3 method for class 'NNCH':
print(x, \dots)
## S3 method for class 'NNCH':
summary(object,file='', id = NULL, k = NULL, r = NULL,
a = NULL, \dots)
## S3 method for class 'NNCH':
plot(x, add.points = TRUE, pch = 21, bgpts = "white",
colpts = "black", cex = 0.7, add = FALSE,
same4all = TRUE, border = NA, percent = rev(seq(10,100, by=10)),
gr = rev(grey(vectorize.parameter(percent)/100*.9)),
id = NULL, k = NULL, r = NULL, a = NULL, ...)
NNCH.asciigrid(x, asc = NULL, cellsize = 1,
percent = rev(seq(10,100, by = 10)),
id = NULL, k = NULL, r = NULL, a = NULL)
NNCH.shapefile(x, percent= rev(seq(10,100, by = 10)),
k = NULL, id = NULL, r = NULL, a = NULL)NNCHxxTRUE if the relocations are to be
plottedadd.points is TRUE, the size of the points
to be used for the plot of the relocations (see par)add.points is TRUE, the background color to
be used for the plot of the relocations (see par)add.points is TRUE, the color of the
points to be used for the plot of the relocations (see par)add.points is TRUE, the size of the
points to be used for the plot of the relocations (see par)TRUE, the plot displaying the home
ranges has the same X and Y limits for all animalsNA if a
border is not requiredascplot, print and summary.NNCH.select returns an object of class NNCH containing a
subset of the original data.
NNCH.asciigrid returns an object of class asc.
NNCH.shapefile returns an object of class shapefile.NNCH.shapefile relies on the package
shapefile.NNCH for further information about the NNCH
methoddata(chamois)
xy <- chamois$locs
(nn <- NNCH(xy, k=c(6,7)))
summary(nn)
NNCH.select(nn, k=7)
## Graphical exploration
plot(nn, k=7)
## rasterization:
asc <- ascgen(chamois$locs,nrcol=100)
asc <- NNCH.asciigrid(nn, k=7, asc=asc)
image(asc)
if (require(shapefiles)) {
(nns <- NNCH.shapefile(nn))
}Run the code above in your browser using DataLab