Arguments
kasc
a raster map of class kasc
points
a data frame with two columns, giving the coordinates of
the species locations
nrep
the number of permutations
h
vector of bandwidths for x and y directions passed to
biv.test, used in the function kde2d of the package
MASS. Defaults to normal reference bandwidth (see ?kde2d).
o.include
logical, passed to biv.test. If TRUE,
the origin is included in the plot
colZ
a color passed to biv.test for the color of the kernel
density estimation of the randomized values
colS
a color passed to biv.test for the actual values of
marginality and tolerance of the object of class enfa
...
further arguments passed to or from other methods