Usage
scatter.enfa(x, xax = 1, yax = 2, h, pts = FALSE,
ncont = 1, clabel = 1, colZ = "blue",
colS = "orange", lwdZ = 2, lwdS = 3,
side = c("top", "bottom", "none"),
csub = 1, ...)Arguments
xax
the column number for the x-axis
yax
the column number for the y-axis
h
vector of bandwidths for x and y directions, used in the
function kde2d of the package MASS. Defaults to
normal reference bandwidth (see ?kde2d)
pts
logical. Whether the points should be drawn. If
FALSE, contours of kernel densities estimates are displayed
ncont
if pts == FALSE, an integer indicating the number
of contour levels desired for the kernel densities estimates. By
default, only the external one is displayed
clabel
a character size for the columns
colZ
color for the kernel density estimates of the available
pixels
colS
color for the kernel density estimates of the used
pixels
lwdZ
if pts==FALSE, the line width for the kernel
density estimates of the available pixels
lwdS
if pts==FALSE, the line width for the kernel
density estimates of the used pixels
side
if "top", the legend of the kept axis is upside, if
"bottom" it is downside, if "none" no legend
csub
a character size for the legend
...
further arguments passed to or from other methods