Usage
plot.sahrlocs(x, ani = names(x$hr), var = names(x$sa),
type = c("hr.in.sa", "locs.in.hr", "locs.in.sa"),
ncla = 4, ylog = FALSE, caxis = 0.7, clab = 0.7,
errbar = c("SE", "CI"), alpha = 0.05, draw = TRUE, ...)Arguments
x
an object of class sahrlocs
ani
a character vector. This vector contains the names
of the animals in x for which habitat selection should be
displayed. At least two animals are required
var
a character vector. This vector contains the names
of the variables in x for which habitat selection should be
displayed
type
a character string. Type of habitat selection that should
be investigated.
If "hr.in.sa", the selection of the home-range within the study
area is displayed. If "locs.in.sa", the selection of the
relocations
ncla
numeric variables are converted to factors. This
parameter controls the number of classes of these factors
ylog
logical. If TRUE, the selection ratios are plotted
on a log scale
caxis
character size on axes to be passed to
par("cex.axis")
clab
character size of axes labels to be passed to
par("cex.lab")
errbar
a character string. Type of error bars: either
"CI" for confidence intervals or "SE" for standard
errors
alpha
the alpha-level for the tests
draw
logical. If FALSE, no plot is drawn
...
further arguments to be passed to the function
plot.wi